r4656 - developers/werner/wlan-spi/vds

werner at docs.openmoko.org werner at docs.openmoko.org
Thu Sep 18 07:24:12 CEST 2008


Author: werner
Date: 2008-09-18 07:24:11 +0200 (Thu, 18 Sep 2008)
New Revision: 4656

Modified:
   developers/werner/wlan-spi/vds/vds.py
Log:
Updated vds.py for the higher data rates of native SPI.



Modified: developers/werner/wlan-spi/vds/vds.py
===================================================================
--- developers/werner/wlan-spi/vds/vds.py	2008-09-18 05:22:49 UTC (rev 4655)
+++ developers/werner/wlan-spi/vds/vds.py	2008-09-18 05:24:11 UTC (rev 4656)
@@ -15,7 +15,7 @@
 s = rigol_ds1000c()
 
 s.hor.pos = 0
-s.hor.scale = 500e-6	# 500us is enough for 100MSa/s
+s.hor.scale = 200e-6	# 200us is enough for 100MSa/s
 
 ch = s.ch[0]
 ch.pos = 1.5
@@ -63,9 +63,11 @@
 	w.save("sdio-"+id)
 
 	# Give the system time to finish booting
+	# -- no need. now that we're really operating at 100MSa/s, the download
+	# takes long enough
 	print "Saved", i, tr, rep
-	time.sleep(60)
-	print "AWAKE"
+#	time.sleep(60)
+#	print "AWAKE"
 
 	# record the kernel messages as well
 	os.system("ssh lab neo dmesg -s 2000000 >dmesg-"+id)




More information about the commitlog mailing list